@@ -13,6 +13,7 @@ from json import dumps
 from treebeard.mp_tree import MP_Node
 import django.core.exceptions
 from treebeard.forms import MoveNodeForm
+from pagetree.reports import ReportableInterface, ReportColumnInterface
 
 
 # dummy it out
@@ -304,7 +305,7 @@ class Section(MP_Node):
         if len(slugs) == 0:
             return (
                 self.hierarchy.get_absolute_url() + "edit/" + self.slug + "/")
-        url = (self.hierarchy.get_absolute_url() + "/edit/".join(slugs)
+        url = (self.hierarchy.get_absolute_url() + "edit/" + "/".join(slugs)
                + "/" + self.slug + "/")
         return url
 
@@ -555,8 +556,10 @@ class Section(MP_Node):
         if not user:
             # no user: the important thing is just that we deny access
             return False, self
+
         # otherwise, let's start at the beginning and check each
-        depth_first_traversal = self.get_root().get_annotated_list()
+        depth_first_traversal = self.get_annotated_list(parent=self.get_root())
+
         # prep a list of all the visits for this user
         upvs = [upv.section.id
                 for upv in list(UserPageVisit.objects.filter(user=user))
@@ -732,6 +735,19 @@ class Version(models.Model):
         return versions
 
 
+class TestReportColumn(ReportColumnInterface):
+
+    def identifier(self):
+        return "Test Report Column"
+
+    def metadata(self):
+        return ['', self.identifier(), "generic",
+                "string", "this is a test"]
+
+    def user_value(self, user):
+        return user.username
+
+
 class TestBlock(models.Model):
     """ this is a pageblock that is exclusively for pagetree's
     internal tests so we have some kind of block to test with
@@ -785,3 +801,11 @@ class TestBlock(models.Model):
             return self.body
         else:
             return self.body[:61] + "..."
+
+    def report_metadata(self):
+        return [TestReportColumn()]
+
+    def report_values(self):
+        return [TestReportColumn()]
+
+ReportableInterface.register(TestBlock)
