@@ -3,7 +3,6 @@ from django.contrib.auth.models import User
 from django.utils import unittest
 from django.http import Http404
 from pagetree.models import Hierarchy, PageBlock, UserPageVisit
-import django.core.exceptions
 import django.db
 
 
@@ -450,10 +449,28 @@ class UserTrackingTest(unittest.TestCase):
         self.section1 = r[0]
         self.section2 = r[1]
         self.section3 = r[2]
+
+        self.h2 = Hierarchy.objects.create(name="other", base_url="")
+        self.h2.get_root().add_child_section_from_dict(
+            {
+                'label': 'Section 1',
+                'slug': 'section-1',
+                'pageblocks': [],
+                'children': [],
+            })
+        self.h2.get_root().add_child_section_from_dict(
+            {
+                'label': 'Section 2',
+                'slug': 'section-1',
+                'pageblocks': [],
+                'children': [],
+            })
+
         self.user = User.objects.create(username='testuser')
 
     def tearDown(self):
         self.h.delete()
+        self.h2.delete()
         self.user.delete()
 
     def test_user_visit(self):
@@ -518,6 +535,15 @@ class UserTrackingTest(unittest.TestCase):
         self.section3.user_pagevisit(self.user, status="complete")
         self.assertEqual(self.section1.gate_check(self.user), (True, None))
 
+    def test_gate_check_multiple_hierarchies(self):
+        children = self.h2.get_root().get_children()
+
+        # first section of any hierarchu returns "True" from gate_check
+        self.assertEqual(
+            children[0].gate_check(self.user), (True, None))
+        self.assertEqual(
+            children[1].gate_check(self.user), (False, children[0]))
+
 
 class VersionTest(unittest.TestCase):
     def setUp(self):
@@ -618,3 +644,69 @@ class VersionTest(unittest.TestCase):
         self.assertEqual(
             len(v.more_recent_versions()),
             1)
+
+
+class MultipleLevelsTest(unittest.TestCase):
+    def setUp(self):
+        self.h = Hierarchy.objects.create(name="main", base_url="")
+        self.root = self.h.get_root()
+        self.root.add_child_section_from_dict(
+            {
+                'label': 'Section 1',
+                'slug': 'section-1',
+                'pageblocks': [],
+                'children': [],
+            })
+        self.root.add_child_section_from_dict(
+            {
+                'label': 'Section 2',
+                'slug': 'section-2',
+                'pageblocks': [],
+                'children': [],
+            })
+        self.root.add_child_section_from_dict(
+            {
+                'label': 'Section 3',
+                'slug': 'section-3',
+                'pageblocks': [],
+                'children': [],
+            })
+        r = self.root.get_children()
+        self.section1 = r[0]
+        self.section2 = r[1]
+        self.section3 = r[2]
+        self.section3.add_child_section_from_dict(
+            {
+                'label': 'Section 4',
+                'slug': 'section-4',
+                'pageblocks': [],
+                'children': [],
+            })
+        self.section4 = self.section3.get_children()[0]
+        self.section4.add_child_section_from_dict(
+            {
+                'label': 'Section 5',
+                'slug': 'section-5',
+                'pageblocks': [],
+                'children': [],
+            })
+        self.section5 = self.section4.get_children()[0]
+
+    def tearDown(self):
+        self.h.delete()
+
+    def test_get_absolute_url(self):
+        self.assertEqual(self.section4.get_absolute_url(),
+                         "section-3/section-4/")
+
+    def test_get_edit_url(self):
+        self.assertEqual(self.section4.get_edit_url(),
+                         "edit/section-3/section-4/")
+
+    def test_get_absolute_url_two_down(self):
+        self.assertEqual(self.section5.get_absolute_url(),
+                         "section-3/section-4/section-5/")
+
+    def test_get_edit_url_two_down(self):
+        self.assertEqual(self.section5.get_edit_url(),
+                         "edit/section-3/section-4/section-5/")
